==> tuia-client-0.8.19.cc-20190806.061431-2-sources.jar: cn/com/tuia/advert/constants/SystemConfigKeyConstant.java <==
package cn.com.tuia.advert.constants;

/**
 * @author: <a href="http://www.panaihua.com">panaihua</a>
 * @date: 2017年03月15日 20:02
 * @descript:
 * @version: 1.0
 */
public interface SystemConfigKeyConstant {

    //单个用户key重复领取的周期时间
    String ADVERT_SINGLE_REPEAT_DAY = "advert.single.repeat.days";

    //广告轮流投放周期
    String ADVERT_TURNS_PUT_COUNT = "advert.turns.put.count";

    //广告轮流投放占比
    String ADVERT_TURNS_PUT_PROPORTION = "advert.turns.put.proportion";

    //开启全部特权媒体
    String APP_PRIVILEGE_ALL = "app.privilege.all";

    //oCPC启用的效果pv次数
    String OCPC_ENABLE_COUNT = "ocpc.enable.count";

    //oCPC最低转换出价(单位:元)
    String OCPC_CONVERT_MIN_PRICE = "ocpc.convert.min.price";

    //移动端 使用 CPC 最低点击单价(单位:元)
    String CPC_CLIENT_MIN_PRICE = "cpc.click.min.price";

    //oCPC最低点击出价(单位:元)
    String OCPC_CLICK_MIN_PRICE = "ocpc.click.min.price";

    //广告定向包预算释放时间
    String ADVERT_PACKAGE_BUDGET_TIME_RELEASE = "advert.package.budget.time.release";

    //用户领取次数开启素材过滤
    String MATERIAL_FILTER_CONSUMER_COUNT = "material.filter.consumer.count";

    //cpc二次确认阈值价格
    String CPC_CONFIRM_THRESHOLD_PRICE = "cpc.confirm.threshold.price";

    //ocpc二次确认阈值价格
    String OCPC_CONFIRM_THRESHOLD_PRICE = "ocpc.confirm.threshold.price";

    //特殊代理商的OCPC最底价(单位:元)
    String SPECIAL_AGENT_OCPC_CONVERT_MIN_PRICE = "special.agent.ocpc.convert.min.price";

    //es集群ip,包含端口，例如：10.26.93.122:9300,10.24.24.138:9300,10.26.48.232:930
    String ELASTIC_SEARCH_CLUSTER_SERVER = "elasticsearch.cluster.server";

    //es集群名称
    String ELASTIC_SEARCH_CLUSTER_NAME = "elasticsearch.cluster.name";

    //重复曝光上限次数
    String MULTIPLE_EXPOSURE_LIMIT_COUNT = "multiple.exposure.limit.count";

    //推啊发送邮件的默认系统发件人信息配置
    String TUIA_MAIL_SYSTEM_SENDER = "tuia.mail.system.sender";

    //手机品牌
    String TUIA_PHONE_BRAND = "tuia.phone.brand";

    //某些特殊的广告位请求算法时，使用场景二的流量分配
    String TUIA_NEZHA_SOLTID_SCENE_TWO = "tuia.nezha.soltId.scene.two";

    //兑吧cpc对低价
    String DUIBA_CPC_FLOOR_PRICE = "duiba.cpc.floor.price";

    //兑吧cpc的折扣率
    String DUIBA_CPC_BID_RATE = "duiba.cpc.bid.rate";

    //某些特殊的广告位请求算法时，使用场景三的流量分配
    String TUIA_NEZHA_SOLTID_SCENE_THREE = "tuia.nezha.soltId.scene.three";

    //行业标签规则过滤的
    String TUIA_TRADE_TAG_RULE = "tuia.trade.tag.rule";

    //行业标签规则计算分值
    String TUIA_TRADE_TAG_RULE_RADIX = "tuia.trade.tag.rule.radix";
    
    // 兑吧未审核时，这些标签代表了兑吧不可投
    String DUIBA_DEFAULT_BANNED_NEWTAGNUM = "duiba.default.banned.newTagNum";
    
    // 广告位限流测试广告
    String TUIA_LIMIT_APPS_SLOT_ADVERT_IDS = "tuia.limit.apps.slot.advert.ids";

    //谢谢参与数
    String TUIA_THKS_PARTAKE_COUNT = "tuia.thks.partake.count";

    //流量分配速率
    String TUIA_FLOW_DISTRIBUTION_RATE = "tuia.flow.distribution.rate";

    //新媒体测试不要测试的配置
    String TUIA_NEW_APP_NOT_TEST_ORIENTATION = "tuia.new.app.not.test.orientation";

    //推啊测试的广告及对应的活动配置
    String TUIA_TEST_ADVERT_ACTIVITY = "tuia.test.advert.activity";

    /** 广告主调整日预算每次调整幅度，全局配置表读取的tuiakey **/
    String BUDGET_ADJUST_LINE_CONFIG_KEY = "tuia.advert.web.budget.per";
    
    // 单用户广告主发券上限设置
    String TUIA_ADVERTISER_LAUNCH_LIMIT = "tuia.advertiser.launch.limit";
    
    // 单用户广告主发券间隔
    String TUIA_ADVERTISER_LAUNCH_INTERVAL = "tuia.advertiser.launch.interval";

    //新行业的特殊落地页标签
    String TUIA_NEWTRADE_PROMOTE_TAG = "tuia.newtrade.promote.tag";

    //新广告扶持的扶持发券数配置
    String TUIA_SUPPORT_ADVERT_LAUNCH = "tuia.support.advert.launch";

    // 福利流量占比缓存 
    String TUIA_ADVERT_WELFARE_FLOW_PERCENT = "tuia.advert.welfare.flow.percent";

    // 判断寡头广告条件 连续三天广告主单日消耗间隔
    String TUIA_GRADE_POINT_LIST ="tuia.grade.point.list";

    // 寡头广告每个间隔 对应的切量比
    String TUIA_GRADE_SCOPE_PROPORTION_LIST="tuia.grade.scope.proportion.list";

    // 判断寡头广告主条件  连续三天消耗占比
    String TUIA_ADVERTISER_CONSUMPTION_PROPORTION = "tuia.advertiser.consumption.proportion";

    // 判断寡头广告主条件 寡头广告连续三天计划都超过金额
    String TUIA_ADVERT_CONSUMPTION = "tuia.advert.consumption";

    //激励广告低arpu值阈值
    String TUIA_ENC_ARPU_THRESHOLD = "tuia.enc.arpu.threshold";

    //已选中的潜力广告行业
    String TUIA_POTENTIAL_TRADELIST = "tuia.potential.tradelist";

    //潜力广告主筛选条件 连续三天单天消耗范围
    String TUIA_ADVERTISER_CONSUMPTION_SCOPE = "tuia.advertiser.consumption.scope";

    //判断潜力广告主 连续三天广告主arup超过值
    String TUIA_ARUP_SCOPE = "tuia.arup.scope";

    //重点扶持的广告主id
    String TUIA_INTENSIVE_ADVERTISER_LIST ="tuia.intensive.advertiser.list";
    //  dmp测试开关
    String DPM_DATA_OPEN = "tuia.dmp.switch";

    //  dmp测试广告
    String DPM_TEST_DATA = "tuia.dmp.data";

    //风控反作弊流量切量比例
    String RISK_CHEAT_PERCENT = "risk.cheat.percent";
    //风控激励广告反作弊流量切量比例
    String RISK_EXCITATION_PERCENT = "risk.excitation.percent";
    //风控激励广告作弊发券
    String RISK_EXCITATION_ADVERT = "risk.excitation.advert";

    //风控反作弊流量测试广告
    String RISK_CHEAT_ADVERT = "risk.cheat.advert";

    //广告在新媒体发券上限
    String TUIA_NEW_APP_LAUNCH_MAX = "tuia.new.app.launch.max";

    //广告在新媒体计费点击上限
    String TUIA_NEW_APP_EFFCLICK_MAX = "tuia.new.app.effclick.max";
    
    //新媒体试投要剔除的广告
    String TUIA_NEW_APP_NOT_TEST_ADVERT = "tuia.new.app.not.test.advert";
    
    // 免费广告主
    String DUIBA_FREE_ADVERTISER = "duiba.free.advertiser";

    // 风控的定向导量广告id
    String RISK_DIRECTION_ADVERT_ID = "risk.direction.advert.id";

    // 天天快报请求下载类广告的包名接口的签名key
    String TTKB_ADVERT_PACKAGE_SIGN_KEY = "ttkb.advert.package.sign.key";
    
    // 重复发券过滤时间间隔
    String TUIA_ADVERT_SINGLE_REPEAT_HOURS = "tuia.advert.single.repeat.hours";

    // 趣闻下载请求下载类广告的包名接口的签名key
    String QUWEN_ADVERT_PACKAGE_SIGN_KEY = "quwen.advert.package.sign.key";
    
    // ocpa广告白名单限制开关，0-关，1-开，默认开
    String TUIA_ADVERT_OCPA_WHITE_SWITCH = "tuia.advert.ocpa.white.switch";
    
    // ocpa广告白名单列表
    String TUIA_ADVERT_OCPA_WHITE_LIST = "tuia.advert.ocpa.white.list";
    
    // 预算平滑广告白名单限制开关，0-关，1-开，默认开
    String TUIA_ADVERT_BUDGET_SMOOTH_WHITE_SWITCH = "tuia.advert.budget.smooth.white.switch";
    
    // 预算平滑广告白名单列表
    String TUIA_ADVERT_BUDGET_SMOOTH_WHITE_LIST = "tuia.advert.budget.smooth.white.list";

    String OCPA_MIN_PRICE = "ocpa.min.price";
    
    // 应急广告配置填充，消耗占比阈值
    String FILL_ADVERT_CONSUMER_ATIO_MAX = "advert.urgent.fill.consume.ratio.max";

    // 新媒体试投，行业不在媒体投放判断阈值，已达到量级的广告个数
    String NEW_APP_TEST_TRADE_SUCCESS_ADVERT_SIZE = "new.app.test.trade.success.advert.size";

    // 新媒体试投，媒体不再投放判断阈值，已达到量级的行业个数
    String NEW_APP_TEST_SUCCESS_TRADE_SIZE = "new.app.test.success.trade.size";

    //潜力广告 10min 媒体的扶持发券量
    String SUPPORT_LAUNCH_COUNT = "potentional.support.launch.count";

    //潜力广告 10min 媒体的扶持发券量
    String APP_LAUNCH_COUNT = "potentional.app.launch.count";

}

==> tuia-client-0.8.21.cc-20190823.103653-7-sources.jar: cn/com/tuia/advert/constants/SystemConfigKeyConstant.java <==
package cn.com.tuia.advert.constants;

/**
 * @author: <a href="http://www.panaihua.com">panaihua</a>
 * @date: 2017年03月15日 20:02
 * @descript:
 * @version: 1.0
 */
public interface SystemConfigKeyConstant {

    //单个用户key重复领取的周期时间
    String ADVERT_SINGLE_REPEAT_DAY = "advert.single.repeat.days";

    //广告轮流投放周期
    String ADVERT_TURNS_PUT_COUNT = "advert.turns.put.count";

    //广告轮流投放占比
    String ADVERT_TURNS_PUT_PROPORTION = "advert.turns.put.proportion";

    //开启全部特权媒体
    String APP_PRIVILEGE_ALL = "app.privilege.all";

    //oCPC启用的效果pv次数
    String OCPC_ENABLE_COUNT = "ocpc.enable.count";

    //oCPC最低转换出价(单位:元)
    String OCPC_CONVERT_MIN_PRICE = "ocpc.convert.min.price";

    //移动端 使用 CPC 最低点击单价(单位:元)
    String CPC_CLIENT_MIN_PRICE = "cpc.click.min.price";

    //oCPC最低点击出价(单位:元)
    String OCPC_CLICK_MIN_PRICE = "ocpc.click.min.price";

    //广告定向包预算释放时间
    String ADVERT_PACKAGE_BUDGET_TIME_RELEASE = "advert.package.budget.time.release";

    //用户领取次数开启素材过滤
    String MATERIAL_FILTER_CONSUMER_COUNT = "material.filter.consumer.count";

    //cpc二次确认阈值价格
    String CPC_CONFIRM_THRESHOLD_PRICE = "cpc.confirm.threshold.price";

    //ocpc二次确认阈值价格
    String OCPC_CONFIRM_THRESHOLD_PRICE = "ocpc.confirm.threshold.price";

    //特殊代理商的OCPC最底价(单位:元)
    String SPECIAL_AGENT_OCPC_CONVERT_MIN_PRICE = "special.agent.ocpc.convert.min.price";

    //es集群ip,包含端口，例如：10.26.93.122:9300,10.24.24.138:9300,10.26.48.232:930
    String ELASTIC_SEARCH_CLUSTER_SERVER = "elasticsearch.cluster.server";

    //es集群名称
    String ELASTIC_SEARCH_CLUSTER_NAME = "elasticsearch.cluster.name";

    //重复曝光上限次数
    String MULTIPLE_EXPOSURE_LIMIT_COUNT = "multiple.exposure.limit.count";

    //推啊发送邮件的默认系统发件人信息配置
    String TUIA_MAIL_SYSTEM_SENDER = "tuia.mail.system.sender";

    //手机品牌
    String TUIA_PHONE_BRAND = "tuia.phone.brand";

    //某些特殊的广告位请求算法时，使用场景二的流量分配
    String TUIA_NEZHA_SOLTID_SCENE_TWO = "tuia.nezha.soltId.scene.two";

    //兑吧cpc对低价
    String DUIBA_CPC_FLOOR_PRICE = "duiba.cpc.floor.price";

    //兑吧cpc的折扣率
    String DUIBA_CPC_BID_RATE = "duiba.cpc.bid.rate";

    //某些特殊的广告位请求算法时，使用场景三的流量分配
    String TUIA_NEZHA_SOLTID_SCENE_THREE = "tuia.nezha.soltId.scene.three";

    //行业标签规则过滤的
    String TUIA_TRADE_TAG_RULE = "tuia.trade.tag.rule";

    //行业标签规则计算分值
    String TUIA_TRADE_TAG_RULE_RADIX = "tuia.trade.tag.rule.radix";
    
    // 兑吧未审核时，这些标签代表了兑吧不可投
    String DUIBA_DEFAULT_BANNED_NEWTAGNUM = "duiba.default.banned.newTagNum";
    
    // 广告位限流测试广告
    String TUIA_LIMIT_APPS_SLOT_ADVERT_IDS = "tuia.limit.apps.slot.advert.ids";

    //谢谢参与数
    String TUIA_THKS_PARTAKE_COUNT = "tuia.thks.partake.count";

    //流量分配速率
    String TUIA_FLOW_DISTRIBUTION_RATE = "tuia.flow.distribution.rate";

    //新媒体测试不要测试的配置
    String TUIA_NEW_APP_NOT_TEST_ORIENTATION = "tuia.new.app.not.test.orientation";

    //推啊测试的广告及对应的活动配置
    String TUIA_TEST_ADVERT_ACTIVITY = "tuia.test.advert.activity";

    /** 广告主调整日预算每次调整幅度，全局配置表读取的tuiakey **/
    String BUDGET_ADJUST_LINE_CONFIG_KEY = "tuia.advert.web.budget.per";
    
    // 单用户广告主发券上限设置
    String TUIA_ADVERTISER_LAUNCH_LIMIT = "tuia.advertiser.launch.limit";
    
    // 单用户广告主发券间隔
    String TUIA_ADVERTISER_LAUNCH_INTERVAL = "tuia.advertiser.launch.interval";

    //新行业的特殊落地页标签
    String TUIA_NEWTRADE_PROMOTE_TAG = "tuia.newtrade.promote.tag";

    //新广告扶持的扶持发券数配置
    String TUIA_SUPPORT_ADVERT_LAUNCH = "tuia.support.advert.launch";

    // 福利流量占比缓存 
    String TUIA_ADVERT_WELFARE_FLOW_PERCENT = "tuia.advert.welfare.flow.percent";

    // 判断寡头广告条件 连续三天广告主单日消耗间隔
    String TUIA_GRADE_POINT_LIST ="tuia.grade.point.list";

    // 寡头广告每个间隔 对应的切量比
    String TUIA_GRADE_SCOPE_PROPORTION_LIST="tuia.grade.scope.proportion.list";

    // 判断寡头广告主条件  连续三天消耗占比
    String TUIA_ADVERTISER_CONSUMPTION_PROPORTION = "tuia.advertiser.consumption.proportion";

    // 判断寡头广告主条件 寡头广告连续三天计划都超过金额
    String TUIA_ADVERT_CONSUMPTION = "tuia.advert.consumption";

    //激励广告低arpu值阈值
    String TUIA_ENC_ARPU_THRESHOLD = "tuia.enc.arpu.threshold";

    //已选中的潜力广告行业
    String TUIA_POTENTIAL_TRADELIST = "tuia.potential.tradelist";

    //潜力广告主筛选条件 连续三天单天消耗范围
    String TUIA_ADVERTISER_CONSUMPTION_SCOPE = "tuia.advertiser.consumption.scope";

    //判断潜力广告主 连续三天广告主arup超过值
    String TUIA_ARUP_SCOPE = "tuia.arup.scope";

    //重点扶持的广告主id
    String TUIA_INTENSIVE_ADVERTISER_LIST ="tuia.intensive.advertiser.list";
    //  dmp测试开关
    String DPM_DATA_OPEN = "tuia.dmp.switch";

    //  dmp测试广告
    String DPM_TEST_DATA = "tuia.dmp.data";

    //风控反作弊流量切量比例
    String RISK_CHEAT_PERCENT = "risk.cheat.percent";
    //风控激励广告反作弊流量切量比例
    String RISK_EXCITATION_PERCENT = "risk.excitation.percent";
    //风控激励广告作弊发券
    String RISK_EXCITATION_ADVERT = "risk.excitation.advert";

    //风控反作弊流量测试广告
    String RISK_CHEAT_ADVERT = "risk.cheat.advert";

    //广告在新媒体发券上限
    String TUIA_NEW_APP_LAUNCH_MAX = "tuia.new.app.launch.max";

    //新媒体试投要剔除的广告
    String TUIA_NEW_APP_NOT_TEST_ADVERT = "tuia.new.app.not.test.advert";
    
    // 免费广告主
    String DUIBA_FREE_ADVERTISER = "duiba.free.advertiser";

    // 风控的定向导量广告id
    String RISK_DIRECTION_ADVERT_ID = "risk.direction.advert.id";

    // 天天快报请求下载类广告的包名接口的签名key
    String TTKB_ADVERT_PACKAGE_SIGN_KEY = "ttkb.advert.package.sign.key";
    
    // 重复发券过滤时间间隔
    String TUIA_ADVERT_SINGLE_REPEAT_HOURS = "tuia.advert.single.repeat.hours";

    // 趣闻下载请求下载类广告的包名接口的签名key
    String QUWEN_ADVERT_PACKAGE_SIGN_KEY = "quwen.advert.package.sign.key";
    
    // ocpa广告白名单限制开关，0-关，1-开，默认开
    String TUIA_ADVERT_OCPA_WHITE_SWITCH = "tuia.advert.ocpa.white.switch";
    
    // ocpa广告白名单列表
    String TUIA_ADVERT_OCPA_WHITE_LIST = "tuia.advert.ocpa.white.list";
    
    // 预算平滑广告白名单限制开关，0-关，1-开，默认开
    String TUIA_ADVERT_BUDGET_SMOOTH_WHITE_SWITCH = "tuia.advert.budget.smooth.white.switch";
    
    // 预算平滑广告白名单列表
    String TUIA_ADVERT_BUDGET_SMOOTH_WHITE_LIST = "tuia.advert.budget.smooth.white.list";

    String OCPA_MIN_PRICE = "ocpa.min.price";
    
    // 应急广告配置填充，消耗占比阈值
    String FILL_ADVERT_CONSUMER_ATIO_MAX = "advert.urgent.fill.consume.ratio.max";

    // 新媒体试投，行业不在媒体投放判断阈值，已达到量级的广告个数
    String NEW_APP_TEST_TRADE_SUCCESS_ADVERT_SIZE = "new.app.test.trade.success.advert.size";

    // 新媒体试投，媒体不再投放判断阈值，已达到量级的行业个数
    String NEW_APP_TEST_SUCCESS_TRADE_SIZE = "new.app.test.success.trade.size";

    // 单个广告同时在测媒体数上限
    String NEW_APP_TEST_ADVERT_LIMIT_APP_SIZE = "new.app.test.advert.limit.app.size";

    //潜力广告 10min 媒体的扶持发券量
    String SUPPORT_LAUNCH_COUNT = "potentional.support.launch.count";

    //潜力广告 10min 媒体的扶持发券量
    String APP_LAUNCH_COUNT = "potentional.app.launch.count";

    //托管底价白名单开关
    String OCPC_BASEPRICE_CONTROL_ENABLESTATE = "tuia.ocpc.baseprice.control.enablestate";

}
